@@ -17,7 +17,7 @@
 #' @return the genesets table from the `clusters` parameter, with results in column "signif_and_reduced"
 #' @export
 reduce_genesets = function(clusters, simscore_threshold = 0.9, universe_fraction = 0.25, signifgenes_fraction = 0.9) {
-  ngenes_signif = genes_signif = rescue_count = ngenes = rescue_score = ngenes_input = NULL # fix invisible bindings R package NOTE
+  id = ngenes_signif = genes_signif = rescue_count = ngenes = rescue_score = ngenes_input = NULL # fix invisible bindings R package NOTE
   # init result column
   clusters$genesets = clusters$genesets |> mutate(signif_and_reduced = signif)
 
@@ -781,6 +781,9 @@ plot_network = function(clusters, src, show_clusters = TRUE, show_text = FALSE,
   # df_clusters$clr = node_color_palette(nrow(df_clusters))
   # df_clusters$fill = lighten_color(df_clusters$clr, 0.25)
 
+  igraph::V(g)$fill = df_clusters$fill[match(igraph::V(g)$cluster, df_clusters$cl)]
+  igraph::V(g)$clr = df_clusters$clr[match(igraph::V(g)$cluster, df_clusters$cl)]
+
 
   p = ggraph::ggraph(g, layout = gl) +
     ggraph::geom_edge_link0(ggplot2::aes(width = I(0.5 + weight / 10),
@@ -809,5 +812,6 @@ plot_network = function(clusters, src, show_clusters = TRUE, show_text = FALSE,
     p = p + ggraph::geom_node_text(ggplot2::aes(label = label), size = 2)
   }
 
+  attr(p, "graph") <- g
   return(p)
 }
